@@ -1,8 +1,7 @@
 from django.template import RequestContext
 from django.test.client import RequestFactory
-from wagtailmenus.conf import constants
-from wagtailmenus.models.menus import ContextualVals, OptionVals
 
+from wagtailmenus.models.menus import ContextualVals, OptionVals
 
 SUB_MENU_TEMPLATE_LIST = (
     'menus/sub_menu_level_2.html',
@@ -12,18 +11,12 @@ SINGLE_ITEM_SUB_MENU_TEMPLATE_LIST = ('menus/sub_menu_level_2.html',)
 
 
 def get_page_model():
-    try:
-        from wagtail.models import Page
-    except ImportError:
-        from wagtail.core.models import Page
+    from wagtail.models import Page
     return Page
 
 
 def get_site_model():
-    try:
-        from wagtail.models import Site
-    except ImportError:
-        from wagtail.core.models import Site
+    from wagtail.models import Site
     return Site
 
 
