@@ -1,21 +1,14 @@
-from wagtail.contrib.modeladmin.options import modeladmin_register
+from wagtail import hooks
+from wagtail.snippets.models import register_snippet
 
 from wagtailmenus.conf import settings
 from wagtailmenus.utils.misc import derive_section_root
-from wagtailmenus.modeladmin import ( # noqa
-    MainMenuAdmin, FlatMenuAdmin, FlatMenuButtonHelper
-)
-try:
-    from wagtail import hooks
-except ImportError:
-    from wagtail.core import hooks
 
 if settings.MAIN_MENUS_EDITABLE_IN_WAGTAILADMIN:
-    modeladmin_register(settings.objects.MAIN_MENUS_MODELADMIN_CLASS)
-
+    register_snippet(settings.objects.MAIN_MENUS_ADMIN_CLASS)
 
 if settings.FLAT_MENUS_EDITABLE_IN_WAGTAILADMIN:
-    modeladmin_register(settings.objects.FLAT_MENUS_MODELADMIN_CLASS)
+    register_snippet(settings.objects.FLAT_MENUS_ADMIN_CLASS)
 
 
 @hooks.register('before_serve_page')
